
#ifndef SENDLATER_EXPORT_H
#define SENDLATER_EXPORT_H

#ifdef SENDLATER_STATIC_DEFINE
#  define SENDLATER_EXPORT
#  define SENDLATER_NO_EXPORT
#else
#  ifndef SENDLATER_EXPORT
#    ifdef KF5SendLater_EXPORTS
        /* We are building this library */
#      define SENDLATER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define SENDLATER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef SENDLATER_NO_EXPORT
#    define SENDLATER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef SENDLATER_DEPRECATED
#  define SENDLATER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef SENDLATER_DEPRECATED_EXPORT
#  define SENDLATER_DEPRECATED_EXPORT SENDLATER_EXPORT SENDLATER_DEPRECATED
#endif

#ifndef SENDLATER_DEPRECATED_NO_EXPORT
#  define SENDLATER_DEPRECATED_NO_EXPORT SENDLATER_NO_EXPORT SENDLATER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef SENDLATER_NO_DEPRECATED
#    define SENDLATER_NO_DEPRECATED
#  endif
#endif

#endif
